You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hivemind.apache.org by ah...@apache.org on 2007/02/21 22:28:15 UTC

svn commit: r510236 [1/2] - in /hivemind/hivemind2/trunk: annotations/src/java/org/apache/hivemind/annotations/internal/ framework/src/java/org/apache/hivemind/definition/ framework/src/java/org/apache/hivemind/definition/impl/ framework/src/java/org/a...

Author: ahuegen
Date: Wed Feb 21 13:28:12 2007
New Revision: 510236

URL: http://svn.apache.org/viewvc?view=rev&rev=510236
Log:
Javadoc for definition package finished
Some naming inconsistencies fixed.

Added:
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ImplementationDefinitionImpl.java
      - copied, changed from r507225, hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceImplementationDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/InterceptorDefinitionImpl.java
      - copied, changed from r507225, hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceInterceptorDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionHelper.java
      - copied, changed from r507225, hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ModuleDefinitionHelper.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedInterceptorDefinitionImpl.java
      - copied, changed from r507225, hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedServiceInterceptorDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/package.html
    hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ClassResolverHolder.java   (contents, props changed)
      - copied, changed from r505487, hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/ClassResolverHolder.java
    hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/ClassResolverHolderImpl.java   (contents, props changed)
      - copied, changed from r505487, hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/impl/ClassResolverHolderImpl.java
    hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/MockRunnable.java   (contents, props changed)
      - copied, changed from r505487, hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/impl/MockRunnable.java
Removed:
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ModuleDefinitionHelper.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedServiceInterceptorDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceImplementationDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceInterceptorDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/ClassResolverHolder.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/impl/ClassResolverHolderImpl.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/impl/MockRunnable.java
Modified:
    hivemind/hivemind2/trunk/annotations/src/java/org/apache/hivemind/annotations/internal/AnnotatedModuleProcessor.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ConfigurationPointDefinition.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ImplementationConstructor.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinition.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinitionPostProcessor.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ServicePointDefinition.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationParserDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationPointDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ContributionDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionPointDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/RegistryDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServicePointDefinitionImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/CoreServicesProvider.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/ProxyUtils.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/StartupImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/EventLinker.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/AutowiringImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/HiveMindClassPool.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/MethodFabImpl.java
    hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/test/HiveMindTestCase.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/FrameworkTestCase.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/SimpleModule.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/StringHolderModule.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestEagerLoader.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestPooledServiceModel.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestServices.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestShutdown.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestStartup.java
    hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestThreadedModel.java
    hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestBeanService.java
    hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestToString.java
    hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestInterceptors.java
    hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestServicePoint.java
    hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/servicemodel/TestRegistryShutdownListenerServices.java
    hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/service/impl/TestLoggingInterceptorFactory.java
    hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlCoreServicesProvider.java
    hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlModuleDescriptorProcessor.java
    hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ConstructClassResolver.xml
    hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/InitializeMethodFailure.xml
    hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/SetClassResolver.xml
    hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/TestBuilderFactory.java

Modified: hivemind/hivemind2/trunk/annotations/src/java/org/apache/hivemind/annotations/internal/AnnotatedModuleProcessor.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/annotations/src/java/org/apache/hivemind/annotations/internal/AnnotatedModuleProcessor.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/annotations/src/java/org/apache/hivemind/annotations/internal/AnnotatedModuleProcessor.java (original)
+++ hivemind/hivemind2/trunk/annotations/src/java/org/apache/hivemind/annotations/internal/AnnotatedModuleProcessor.java Wed Feb 21 13:28:12 2007
@@ -39,7 +39,7 @@
 import org.apache.hivemind.definition.impl.ConfigurationPointDefinitionImpl;
 import org.apache.hivemind.definition.impl.ContributionDefinitionImpl;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceImplementationDefinitionImpl;
+import org.apache.hivemind.definition.impl.ImplementationDefinitionImpl;
 import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
 import org.apache.hivemind.util.ClasspathResource;
 import org.apache.hivemind.util.IdUtils;
@@ -248,7 +248,7 @@
         ImplementationConstructor constructor = new MethodCallImplementationConstructor(location, 
                 method, instanceProvider);
 
-        ImplementationDefinition sid = new ServiceImplementationDefinitionImpl(module, location, 
+        ImplementationDefinition sid = new ImplementationDefinitionImpl(module, location, 
                 constructor, service.serviceModel(), true);
 
         spd.addImplementation(sid);

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ConfigurationPointDefinition.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ConfigurationPointDefinition.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ConfigurationPointDefinition.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ConfigurationPointDefinition.java Wed Feb 21 13:28:12 2007
@@ -44,15 +44,16 @@
     /**
      * Adds a contribution.
      * @param contribution  the contribution
-     * @throws ApplicationRuntimeException  if this point is not visible from contribution
+     * @throws ApplicationRuntimeException  if this point is not visible from the 
+     *   module that defines the contribution
      */
     public void addContribution(ContributionDefinition contribution);
 
     /**
      * Adds a parser definition.
      * @param parser  the parser
-     * @throws ApplicationRuntimeException  if this point is not visible from parser
-     *   or if a parser for the specified format is already defined
+     * @throws ApplicationRuntimeException  if this point is not visible from the module 
+     *   that defines the parser or if a parser for the specified format is already defined
      */
     public void addParser(ConfigurationParserDefinition parser);
     
@@ -67,4 +68,4 @@
      * @return  returns all parsers as instances of {@link ConfigurationParserDefinition}
      */
     public Collection getParsers();
-}
\ No newline at end of file
+}

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ImplementationConstructor.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ImplementationConstructor.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ImplementationConstructor.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ImplementationConstructor.java Wed Feb 21 13:28:12 2007
@@ -25,7 +25,9 @@
 public interface ImplementationConstructor extends Locatable
 {
     /**
-     * Creates a new core service implementation.
+     * Creates a new core service implementation. Can be called multiple times
+     * for service models like pooled or threaded.
+     * 
      * @param context  the context of the construction
      */
     public Object constructCoreServiceImplementation(ImplementationConstructionContext context);

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinition.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinition.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinition.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinition.java Wed Feb 21 13:28:12 2007
@@ -26,9 +26,8 @@
  * which build a registry. The definition is a blueprint from which
  * a registry instance is constructed. 
  * 
- * After the complete definition of all elements of a registry
- * the definition is passed to {@link RegistryBuilder} for
- * the next phase: the registry construction. 
+ * The definition is passed to {@link RegistryBuilder} for the next phase: 
+ * the registry construction. 
  * From that moment on the definition shouldn't be changed any longer.
  * 
  * @author Achim Huegen

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinitionPostProcessor.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinitionPostProcessor.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinitionPostProcessor.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/RegistryDefinitionPostProcessor.java Wed Feb 21 13:28:12 2007
@@ -16,6 +16,13 @@
 
 import org.apache.hivemind.ErrorHandler;
 
+/**
+ * Interface for post processors that want to get after the definition phase
+ * of a registry before the registry is started up.
+ * A post processor is allowed to alter the definition structure.
+ * 
+ * @author Huegen
+ */
 public interface RegistryDefinitionPostProcessor
 {
     /**
@@ -23,8 +30,8 @@
      * That means, all extension points of all modules are now known to the registry
      * definition.
      * 
-     * @param registryDefinition
-     * @param errorHandler
+     * @param registryDefinition  the definition
+     * @param errorHandler  an handler for the reporting of recoverable errors
      */
     public void postprocess(RegistryDefinition registryDefinition, ErrorHandler errorHandler);
 

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ServicePointDefinition.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ServicePointDefinition.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ServicePointDefinition.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ServicePointDefinition.java Wed Feb 21 13:28:12 2007
@@ -16,6 +16,8 @@
 
 import java.util.Collection;
 
+import org.apache.hivemind.ApplicationRuntimeException;
+
 /**
  * Defines a service extension point.
  * The definition includes the service interface, implementations and interceptors.
@@ -39,6 +41,8 @@
     /**
      * Adds an implementation definition to the service point.
      * @param implementation  the implementation
+     * @throws ApplicationRuntimeException  if this point is not visible from the module
+     *    that defines the implementation
      */
     public void addImplementation(ImplementationDefinition implementation);
 
@@ -55,6 +59,8 @@
     /**
      * Adds an interceptor definition to the service point.
      * @param interceptor  the interceptor
+     * @throws ApplicationRuntimeException  if this point is not visible from the module 
+     *   that defines the interceptor.
      */
     public void addInterceptor(InterceptorDefinition interceptor);
 

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationParserDefinitionImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationParserDefinitionImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationParserDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationParserDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -19,6 +19,11 @@
 import org.apache.hivemind.definition.ConfigurationParserDefinition;
 import org.apache.hivemind.definition.ModuleDefinition;
 
+/**
+ * Default implementation of {@link ConfigurationParserDefinition}.
+ * 
+ * @author Achim Huegen
+ */
 public class ConfigurationParserDefinitionImpl extends ExtensionDefinitionImpl implements ConfigurationParserDefinition
 {
     private String _inputFormat;

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationPointDefinitionImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationPointDefinitionImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationPointDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ConfigurationPointDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -31,6 +31,11 @@
 import org.apache.hivemind.definition.Occurances;
 import org.apache.hivemind.definition.Visibility;
 
+/**
+ * Default implementation of {@link ConfigurationPointDefinition}.
+ * 
+ * @author Achim Huegen
+ */
 public class ConfigurationPointDefinitionImpl extends ExtensionPointDefinitionImpl implements ConfigurationPointDefinition
 {
     private String _containerClassName;
@@ -79,7 +84,7 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ConfigurationPointDefinition#setExpectedContributions(org.apache.hivemind.definition.Occurances)
+     * Sets the expected number of contributions to the configuration.
      */
     public void setExpectedContributions(Occurances expectedContributions)
     {

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ContributionDefinitionImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ContributionDefinitionImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ContributionDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ContributionDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -19,9 +19,14 @@
 import org.apache.hivemind.definition.ContributionDefinition;
 import org.apache.hivemind.definition.ModuleDefinition;
 
+/**
+ * Default implementation of {@link ContributionDefinition}.
+ * 
+ * @author Achim Huegen
+ */
 public class ContributionDefinitionImpl extends ExtensionDefinitionImpl implements ContributionDefinition
 {
-    private Contribution _contributionConstructor;
+    private Contribution _contribution;
     private boolean _initial;
 
     public ContributionDefinitionImpl(ModuleDefinition module)
@@ -30,10 +35,10 @@
     }
 
     public ContributionDefinitionImpl(ModuleDefinition module, Location location,
-            Contribution contributionConstructor, boolean initial)
+            Contribution contribution, boolean initial)
     {
         super(module, location);
-        _contributionConstructor = contributionConstructor;
+        _contribution = contribution;
         _initial = initial;
     }
 
@@ -42,15 +47,15 @@
      */
     public Contribution getContribution()
     {
-        return _contributionConstructor;
+        return _contribution;
     }
 
     /**
-     * @see org.apache.hivemind.definition.ContributionDefinition#setContributionConstructor(org.apache.hivemind.definition.Contribution)
+     * Sets the contribution implementation.
      */
-    public void setContributionConstructor(Contribution contributionConstructor)
+    public void setContribution(Contribution contribution)
     {
-        _contributionConstructor = contributionConstructor;
+        _contribution = contribution;
     }
 
     /**

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionDefinitionImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionDefinitionImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -19,6 +19,11 @@
 import org.apache.hivemind.definition.ModuleDefinition;
 import org.apache.hivemind.util.Defense;
 
+/**
+ * Default implementation of {@link ExtensionDefinition}.
+ * 
+ * @author Achim Huegen
+ */
 public class ExtensionDefinitionImpl implements ExtensionDefinition
 {
     private Location _location;
@@ -61,7 +66,7 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ExtensionDefinition#setLocation(org.apache.hivemind.Location)
+     * Sets the location of the extension.
      */
     public void setLocation(Location location)
     {

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionPointDefinitionImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionPointDefinitionImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionPointDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ExtensionPointDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -20,6 +20,11 @@
 import org.apache.hivemind.definition.Visibility;
 import org.apache.hivemind.util.Defense;
 
+/**
+ * Default implementation of {@link ExtensionPointDefinition}.
+ * 
+ * @author Achim Huegen
+ */
 public class ExtensionPointDefinitionImpl implements ExtensionPointDefinition
 {
     private ModuleDefinition _module;
@@ -52,6 +57,9 @@
         return _module.getId();
     }
 
+    /**
+     * @return the module that defined this extension point.
+     */
     protected ModuleDefinition getModule()
     {
         return _module;
@@ -74,7 +82,8 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ExtensionPointDefinition#setId(java.lang.String)
+     * Sets the id of the extension point.
+     * @param id  the id (unqualified without module id)
      */
     public void setId(String id)
     {
@@ -90,7 +99,7 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ExtensionPointDefinition#setLocation(org.apache.hivemind.Location)
+     * Sets the location of the extension point.
      */
     public void setLocation(Location location)
     {
@@ -106,7 +115,7 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ExtensionPointDefinition#setVisibility(org.apache.hivemind.definition.Visibility)
+     * Sets the visibility of the extension point.
      */
     public void setVisibility(Visibility visibility)
     {

Copied: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ImplementationDefinitionImpl.java (from r507225, hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceImplementationDefinitionImpl.java)
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ImplementationDefinitionImpl.java?view=diff&rev=510236&p1=hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceImplementationDefinitionImpl.java&r1=507225&p2=hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ImplementationDefinitionImpl.java&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceImplementationDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ImplementationDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -16,28 +16,33 @@
 
 import org.apache.hivemind.Location;
 import org.apache.hivemind.definition.ImplementationConstructor;
-import org.apache.hivemind.definition.ModuleDefinition;
 import org.apache.hivemind.definition.ImplementationDefinition;
+import org.apache.hivemind.definition.ModuleDefinition;
 
-public class ServiceImplementationDefinitionImpl extends ExtensionDefinitionImpl implements
+/**
+ * Default implementation of {@link ImplementationDefinition}.
+ * 
+ * @author Achim Huegen
+ */
+public class ImplementationDefinitionImpl extends ExtensionDefinitionImpl implements
         ImplementationDefinition
 {
     private String _serviceModel;
 
-    private ImplementationConstructor _serviceConstructor;
+    private ImplementationConstructor _implementationConstructor;
 
     private boolean _isDefault;
 
-    public ServiceImplementationDefinitionImpl(ModuleDefinition module)
+    public ImplementationDefinitionImpl(ModuleDefinition module)
     {
         super(module);
     }
 
-    public ServiceImplementationDefinitionImpl(ModuleDefinition module, Location location,
-            ImplementationConstructor serviceConstructor, String serviceModel, boolean isDefault)
+    public ImplementationDefinitionImpl(ModuleDefinition module, Location location,
+            ImplementationConstructor implementationConstructor, String serviceModel, boolean isDefault)
     {
         super(module, location);
-        _serviceConstructor = serviceConstructor;
+        _implementationConstructor = implementationConstructor;
         _serviceModel = serviceModel;
         _isDefault = isDefault;
     }
@@ -51,11 +56,11 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ImplementationDefinition#setServiceModel(java.lang.String)
+     * Sets the service model of the implementation.
      */
-    public void setServiceModel(String interfaceClassName)
+    public void setServiceModel(String serviceModel)
     {
-        _serviceModel = interfaceClassName;
+        _serviceModel = serviceModel;
     }
 
     /**
@@ -67,7 +72,8 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ImplementationDefinition#setDefault(boolean)
+     * Sets the default attribute of the implementation.
+     * @param isDefault   true, if this implementation is the default one
      */
     public void setDefault(boolean isDefault)
     {
@@ -79,15 +85,16 @@
      */
     public ImplementationConstructor getServiceConstructor()
     {
-        return _serviceConstructor;
+        return _implementationConstructor;
     }
 
     /**
-     * @see org.apache.hivemind.definition.ImplementationDefinition#setServiceConstructor(org.apache.hivemind.definition.ImplementationConstructor)
+     * Sets the constructor implementation that is used for the creation of
+     * the implementation instance.
      */
-    public void setServiceConstructor(ImplementationConstructor serviceConstructor)
+    public void setImplementationConstructor(ImplementationConstructor serviceConstructor)
     {
-        _serviceConstructor = serviceConstructor;
+        _implementationConstructor = serviceConstructor;
     }
 
 }

Copied: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/InterceptorDefinitionImpl.java (from r507225, hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceInterceptorDefinitionImpl.java)
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/InterceptorDefinitionImpl.java?view=diff&rev=510236&p1=hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceInterceptorDefinitionImpl.java&r1=507225&p2=hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/InterceptorDefinitionImpl.java&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServiceInterceptorDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/InterceptorDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -16,24 +16,27 @@
 
 import org.apache.hivemind.Location;
 import org.apache.hivemind.definition.InterceptorConstructor;
-import org.apache.hivemind.definition.ModuleDefinition;
 import org.apache.hivemind.definition.InterceptorDefinition;
+import org.apache.hivemind.definition.ModuleDefinition;
 
 /**
+ * Default implementation of {@link InterceptorDefinition}.
  * Implementations of this interface may additionally implement the {@link org.apache.hivemind.Orderable}
  * interface if a certain interceptor order is required.
+ * 
+ * @author Achim Huegen
  */
-public class ServiceInterceptorDefinitionImpl extends ExtensionDefinitionImpl implements InterceptorDefinition
+public class InterceptorDefinitionImpl extends ExtensionDefinitionImpl implements InterceptorDefinition
 {
     private InterceptorConstructor _interceptorConstructor;
     private String _name;
 
-    public ServiceInterceptorDefinitionImpl(ModuleDefinition module)
+    public InterceptorDefinitionImpl(ModuleDefinition module)
     {
         super(module);
     }
 
-    public ServiceInterceptorDefinitionImpl(ModuleDefinition module, String name, Location location,
+    public InterceptorDefinitionImpl(ModuleDefinition module, String name, Location location,
             InterceptorConstructor interceptorConstructor)
     {
         super(module, location);
@@ -50,11 +53,11 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.InterceptorDefinition#setInterceptorConstructor(org.apache.hivemind.definition.InterceptorConstructor)
+     * Sets the constructor implementation responsible for the creation of interceptor instances.
      */
-    public void setInterceptorConstructor(InterceptorConstructor serviceConstructor)
+    public void setInterceptorConstructor(InterceptorConstructor interceptorConstructor)
     {
-        _interceptorConstructor = serviceConstructor;
+        _interceptorConstructor = interceptorConstructor;
     }
 
     /**
@@ -66,7 +69,7 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.InterceptorDefinition#setName(java.lang.String)
+     * Sets the name of the interceptor.
      */
     public void setName(String name)
     {

Copied: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionHelper.java (from r507225, hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ModuleDefinitionHelper.java)
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionHelper.java?view=diff&rev=510236&p1=hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ModuleDefinitionHelper.java&r1=507225&p2=hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionHelper.java&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/ModuleDefinitionHelper.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionHelper.java Wed Feb 21 13:28:12 2007
@@ -12,13 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.hivemind.definition;
+package org.apache.hivemind.definition.impl;
 
-import org.apache.hivemind.definition.impl.ConfigurationPointDefinitionImpl;
-import org.apache.hivemind.definition.impl.ContributionDefinitionImpl;
-import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceImplementationDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
+import org.apache.hivemind.definition.ConfigurationPointDefinition;
+import org.apache.hivemind.definition.Contribution;
+import org.apache.hivemind.definition.ContributionDefinition;
+import org.apache.hivemind.definition.ImplementationConstructor;
+import org.apache.hivemind.definition.ImplementationDefinition;
+import org.apache.hivemind.definition.ModuleDefinition;
+import org.apache.hivemind.definition.Occurances;
+import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.Visibility;
 import org.apache.hivemind.impl.CreateClassServiceConstructor;
 import org.apache.hivemind.internal.ServiceModel;
 
@@ -62,7 +66,7 @@
             )
     {
         // These implementations override the inline implementations, so default is true here
-        ImplementationDefinition result = new ServiceImplementationDefinitionImpl(_module, _module
+        ImplementationDefinition result = new ImplementationDefinitionImpl(_module, _module
                 .getLocation(), constructor, serviceModel, true);
         servicePoint.addImplementation(result);
         return result;

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ModuleDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -27,12 +27,18 @@
 import org.apache.hivemind.definition.ConfigurationPointDefinition;
 import org.apache.hivemind.definition.ContributionDefinition;
 import org.apache.hivemind.definition.DefinitionMessages;
+import org.apache.hivemind.definition.ExtensionDefinition;
 import org.apache.hivemind.definition.ModuleDefinition;
 import org.apache.hivemind.definition.ImplementationDefinition;
 import org.apache.hivemind.definition.InterceptorDefinition;
 import org.apache.hivemind.definition.ServicePointDefinition;
 import org.apache.hivemind.definition.UnresolvedExtension;
 
+/**
+ * Default implementation of {@link ExtensionDefinition}.
+ * 
+ * @author Achim Huegen
+ */
 public class ModuleDefinitionImpl implements ModuleDefinition
 {
     private String _id;
@@ -62,8 +68,8 @@
     }
 
     /**
-     * @param id
-     * @param location
+     * @param id  the id of the module 
+     * @param location  the location of the module 
      * @param resolver the {@link ClassResolver} used to resolve all classes referenced from 
      *          elements inside this module.
      * @param packageName  name of the package to search for class names within. If null, it defaults to the id 
@@ -104,7 +110,7 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ModuleDefinition#setLocation(org.apache.hivemind.Location)
+     * Sets the location of the module.
      */
     public void setLocation(Location location)
     {
@@ -120,7 +126,7 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ModuleDefinition#setId(java.lang.String)
+     * Sets the id of the module.
      */
     public void setId(String moduleId)
     {
@@ -136,7 +142,7 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ModuleDefinition#setPackageName(java.lang.String)
+     * Sets the package name of the module.
      */
     public void setPackageName(String packageName)
     {

Copied: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedInterceptorDefinitionImpl.java (from r507225, hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedServiceInterceptorDefinitionImpl.java)
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedInterceptorDefinitionImpl.java?view=diff&rev=510236&p1=hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedServiceInterceptorDefinitionImpl.java&r1=507225&p2=hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedInterceptorDefinitionImpl.java&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedServiceInterceptorDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/OrderedInterceptorDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -23,16 +23,15 @@
 import org.apache.hivemind.definition.ModuleDefinition;
 
 /**
- * Specialization of {@link ServiceInterceptorDefinitionImpl} that implements the {@link Orderable}
+ * Specialization of {@link InterceptorDefinitionImpl} that implements the {@link Orderable}
  * interface.
  */
-public class OrderedServiceInterceptorDefinitionImpl extends ServiceInterceptorDefinitionImpl implements Orderable
+public class OrderedInterceptorDefinitionImpl extends InterceptorDefinitionImpl implements Orderable
 {
-
     private String _precedingInterceptorIds;
     private String _followingInterceptorIds;
 
-    public OrderedServiceInterceptorDefinitionImpl(ModuleDefinition module, String name, Location location, InterceptorConstructor interceptorConstructor,
+    public OrderedInterceptorDefinitionImpl(ModuleDefinition module, String name, Location location, InterceptorConstructor interceptorConstructor,
             String precedingInterceptorIds, String followingInterceptorIds)
     {
         super(module, name, location, interceptorConstructor);

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/RegistryDefinitionImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/RegistryDefinitionImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/RegistryDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/RegistryDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -34,11 +34,7 @@
 import org.apache.hivemind.util.IdUtils;
 
 /**
- * Implementation of {@link RegistryDefinition}.
- * 
- * The order of additions of 
- * registry parts is arbitrary. For example there is no guarantee that a configuration
- * point is added before a corresponding contribution is added. 
+ * Default implementation of {@link RegistryDefinition}.
  * 
  * @author Achim Huegen
  */

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServicePointDefinitionImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServicePointDefinitionImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServicePointDefinitionImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/ServicePointDefinitionImpl.java Wed Feb 21 13:28:12 2007
@@ -23,12 +23,17 @@
 import org.apache.hivemind.Location;
 import org.apache.hivemind.definition.DefinitionMessages;
 import org.apache.hivemind.definition.ExtensionDefinition;
-import org.apache.hivemind.definition.ModuleDefinition;
 import org.apache.hivemind.definition.ImplementationDefinition;
 import org.apache.hivemind.definition.InterceptorDefinition;
+import org.apache.hivemind.definition.ModuleDefinition;
 import org.apache.hivemind.definition.ServicePointDefinition;
 import org.apache.hivemind.definition.Visibility;
 
+/**
+ * Default implementation of {@link ServicePointDefinition}.
+ * 
+ * @author Achim Huegen
+ */
 public class ServicePointDefinitionImpl extends ExtensionPointDefinitionImpl implements ServicePointDefinition
 {
     private String _interfaceClassName;
@@ -57,7 +62,10 @@
     }
 
     /**
-     * @see org.apache.hivemind.definition.ServicePointDefinition#setInterfaceClassName(java.lang.String)
+     * Sets the class name of the service interface.
+     * 
+     * @param interfaceClassName the fully qualified class name of the service interface. 
+     *          This may be the name of a ordinary class or an interface.
      */
     public void setInterfaceClassName(String interfaceClassName)
     {

Added: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/package.html
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/package.html?view=auto&rev=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/package.html (added)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/definition/impl/package.html Wed Feb 21 13:28:12 2007
@@ -0,0 +1,20 @@
+<!-- $Id: package.html 189017 2004-02-26 23:08:04 +0000 (Do, 26 Feb 2004) hlship $ -->
+<!-- 
+   Copyright 2004 The Apache Software Foundation
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+-->
+	
+<body>
+Default implementations of the registry definition API.
+</body>
\ No newline at end of file

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/CoreServicesProvider.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/CoreServicesProvider.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/CoreServicesProvider.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/CoreServicesProvider.java Wed Feb 21 13:28:12 2007
@@ -31,9 +31,9 @@
 import org.apache.hivemind.definition.ImplementationConstructionContext;
 import org.apache.hivemind.definition.ImplementationConstructor;
 import org.apache.hivemind.definition.ModuleDefinition;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.RegistryDefinition;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.impl.servicemodel.PooledServiceModelFactory;
 import org.apache.hivemind.impl.servicemodel.PrimitiveServiceModelFactory;

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/ProxyUtils.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/ProxyUtils.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/ProxyUtils.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/ProxyUtils.java Wed Feb 21 13:28:12 2007
@@ -179,7 +179,7 @@
 
     /**
      * We construct a method that always goes through this service model's
-     * {@link #getServiceImplementationForCurrentThread())} method.
+     * {@link #getServiceImplementationForCurrentThread()} method.
      */
     private static void addServiceAccessor(ClassFab classFab, String serviceModelMethodName,
             ServicePoint servicePoint)

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/StartupImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/StartupImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/StartupImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/impl/StartupImpl.java Wed Feb 21 13:28:12 2007
@@ -20,7 +20,7 @@
 /**
  * Startup service for the HiveMind Registry. This service is invoked as the
  * {@link org.apache.hivemind.internal.RegistryInfrastructure#startup() last step} of the
- * {@link org.apache.hivemind.impl.RegistryBuilder#constructRegistry(Locale) registry construction}.
+ * {@link org.apache.hivemind.impl.RegistryBuilder#constructRegistry(java.util.Locale) registry construction}.
  * All contributions (java.lang.Runnable objects) to the <code>hivemind.Startup</code>
  * configuration point are executed serially in an arbitrary order. Note that the contributions are
  * <em>not</em> executed in separate Threads.

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/EventLinker.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/EventLinker.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/EventLinker.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/EventLinker.java Wed Feb 21 13:28:12 2007
@@ -37,8 +37,6 @@
      *            the object which will be added as a listener.
      * @param location
      *            used when reporting errors, may be null
-     * @return true on success, false if there was any failure (which may mean only partial
-     *         registration).
      */
     public void addEventListener(Object producer, String eventSetName, Object consumer,
             Location location);

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/AutowiringImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/AutowiringImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/AutowiringImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/AutowiringImpl.java Wed Feb 21 13:28:12 2007
@@ -64,8 +64,9 @@
     }
     
     /**
-     * @param context
+     * @param registry  reference to registry 
      * @param strategyContributions  list with instances of {@link AutowiringStrategyContribution}
+     * @param errorHandler  handler for dealing with recoverable errors.
      */
     public AutowiringImpl(RegistryInfrastructure registry, List strategyContributions, ErrorHandler errorHandler)
     {

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/HiveMindClassPool.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/HiveMindClassPool.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/HiveMindClassPool.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/HiveMindClassPool.java Wed Feb 21 13:28:12 2007
@@ -72,6 +72,6 @@
      */
     public Class toClass(CtClass ctClass) throws CannotCompileException
     {
-        return ctClass.toClass(_loader);
+        return ctClass.toClass(_loader, this.getClass().getProtectionDomain());
     }
 }

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/MethodFabImpl.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/MethodFabImpl.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/MethodFabImpl.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/service/impl/MethodFabImpl.java Wed Feb 21 13:28:12 2007
@@ -25,7 +25,7 @@
 
 /**
  * Implementation of {@link org.apache.hivemind.service.MethodFab}, which is returned from
- * {@link org.apache.hivemind.service.ClassFab#addMethod(int, String, Class, Class[], Class[], String)},
+ * {@link org.apache.hivemind.service.ClassFab#addMethod(int, MethodSignature, String)},
  * so that additional exception handlers may be attached to the added method.
  * 
  * @author Howard Lewis Ship

Modified: hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/test/HiveMindTestCase.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/test/HiveMindTestCase.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/test/HiveMindTestCase.java (original)
+++ hivemind/hivemind2/trunk/framework/src/java/org/apache/hivemind/test/HiveMindTestCase.java Wed Feb 21 13:28:12 2007
@@ -465,7 +465,7 @@
      * Accesses the control for a previously created mock object. Iterates over the list of managed
      * controls until one is found whose mock object identity equals the mock object provided.
      * 
-     * @param Mock
+     * @param mock
      *            object whose control is needed
      * @return the corresponding MockControl if found
      * @throws IllegalArgumentException

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/FrameworkTestCase.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/FrameworkTestCase.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/FrameworkTestCase.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/FrameworkTestCase.java Wed Feb 21 13:28:12 2007
@@ -25,7 +25,7 @@
 import org.apache.hivemind.definition.Visibility;
 import org.apache.hivemind.definition.impl.ConfigurationPointDefinitionImpl;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceImplementationDefinitionImpl;
+import org.apache.hivemind.definition.impl.ImplementationDefinitionImpl;
 import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
 import org.apache.hivemind.impl.CreateClassServiceConstructor;
 import org.apache.hivemind.impl.DefaultClassResolver;
@@ -87,7 +87,7 @@
      */
     protected ImplementationDefinition createServiceImplementationDefinition(ModuleDefinition module, Class serviceImplementationClass)
     {
-        ImplementationDefinition result = new ServiceImplementationDefinitionImpl(module, newLocation(),
+        ImplementationDefinition result = new ImplementationDefinitionImpl(module, newLocation(),
                 new CreateClassServiceConstructor(newLocation(), serviceImplementationClass.getName()), 
                 "singleton", true);
 

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/SimpleModule.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/SimpleModule.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/SimpleModule.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/SimpleModule.java Wed Feb 21 13:28:12 2007
@@ -18,8 +18,8 @@
 
 import org.apache.hivemind.Location;
 import org.apache.hivemind.Resource;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.impl.DefaultClassResolver;
 import org.apache.hivemind.impl.LocationImpl;

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/StringHolderModule.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/StringHolderModule.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/StringHolderModule.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/StringHolderModule.java Wed Feb 21 13:28:12 2007
@@ -22,11 +22,11 @@
 import org.apache.hivemind.ApplicationRuntimeException;
 import org.apache.hivemind.InterceptorStack;
 import org.apache.hivemind.definition.InterceptorConstructor;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.InterceptorDefinition;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceInterceptorDefinitionImpl;
+import org.apache.hivemind.definition.impl.InterceptorDefinitionImpl;
 import org.apache.hivemind.impl.DefaultClassResolver;
 import org.apache.hivemind.internal.AbstractServiceInterceptorConstructor;
 import org.apache.hivemind.internal.Module;
@@ -66,7 +66,7 @@
                 }
                 interceptorStack.push(interceptor);
             }};
-        InterceptorDefinition interceptor = new ServiceInterceptorDefinitionImpl(helper.getModule(), "hivemind.LoggingInterceptor", getLocation(), constructor);
+        InterceptorDefinition interceptor = new InterceptorDefinitionImpl(helper.getModule(), "hivemind.LoggingInterceptor", getLocation(), constructor);
         sp.addInterceptor(interceptor);
     }
 }

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestEagerLoader.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestEagerLoader.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestEagerLoader.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestEagerLoader.java Wed Feb 21 13:28:12 2007
@@ -23,8 +23,8 @@
 import org.apache.hivemind.Registry;
 import org.apache.hivemind.definition.Contribution;
 import org.apache.hivemind.definition.ContributionContext;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.internal.ServiceModel;
 import org.apache.hivemind.internal.ServicePoint;

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestPooledServiceModel.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestPooledServiceModel.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestPooledServiceModel.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestPooledServiceModel.java Wed Feb 21 13:28:12 2007
@@ -22,7 +22,7 @@
 import org.apache.hivemind.service.ThreadEventNotifier;
 
 /**
- * Tests {@link org.apache.hivemind.impl.PooledServiceModel}. 
+ * Tests {@link org.apache.hivemind.impl.servicemodel.PooledServiceModel}. 
  *
  * @author Howard Lewis Ship
  */

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestServices.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestServices.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestServices.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestServices.java Wed Feb 21 13:28:12 2007
@@ -35,11 +35,11 @@
 import org.apache.hivemind.definition.InterceptorConstructor;
 import org.apache.hivemind.definition.InterceptorDefinition;
 import org.apache.hivemind.definition.ModuleDefinition;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
-import org.apache.hivemind.definition.impl.OrderedServiceInterceptorDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceInterceptorDefinitionImpl;
+import org.apache.hivemind.definition.impl.OrderedInterceptorDefinitionImpl;
+import org.apache.hivemind.definition.impl.InterceptorDefinitionImpl;
 import org.apache.hivemind.internal.AbstractServiceImplementationConstructor;
 import org.apache.hivemind.internal.AbstractServiceInterceptorConstructor;
 import org.apache.hivemind.internal.Module;
@@ -95,11 +95,11 @@
         ModuleDefinition module = new SimpleModule();
         ServicePointDefinition servicePoint = module.getServicePoint("Simple");
         
-        InterceptorDefinition interceptor1 = new OrderedServiceInterceptorDefinitionImpl(module, "Fred", newLocation(), new TrackerServiceInterceptorConstructor("Fred"), "Barney", null);
+        InterceptorDefinition interceptor1 = new OrderedInterceptorDefinitionImpl(module, "Fred", newLocation(), new TrackerServiceInterceptorConstructor("Fred"), "Barney", null);
         servicePoint.addInterceptor(interceptor1);
-        InterceptorDefinition interceptor2 = new OrderedServiceInterceptorDefinitionImpl(module, "Barney", newLocation(), new TrackerServiceInterceptorConstructor("Barney"), null, null);
+        InterceptorDefinition interceptor2 = new OrderedInterceptorDefinitionImpl(module, "Barney", newLocation(), new TrackerServiceInterceptorConstructor("Barney"), null, null);
         servicePoint.addInterceptor(interceptor2);
-        InterceptorDefinition interceptor3 = new OrderedServiceInterceptorDefinitionImpl(module, "Wilma", newLocation(), new TrackerServiceInterceptorConstructor("Wilma"), null, "Barney");
+        InterceptorDefinition interceptor3 = new OrderedInterceptorDefinitionImpl(module, "Wilma", newLocation(), new TrackerServiceInterceptorConstructor("Wilma"), null, "Barney");
         servicePoint.addInterceptor(interceptor3);
         
         Registry r =
@@ -216,7 +216,7 @@
                 }
                 interceptorStack.push(interceptor);
             }};
-        InterceptorDefinition interceptor = new ServiceInterceptorDefinitionImpl(module, "hivemind.LoggingInterceptor", module.getLocation(), constructor);
+        InterceptorDefinition interceptor = new InterceptorDefinitionImpl(module, "hivemind.LoggingInterceptor", module.getLocation(), constructor);
         sp.addInterceptor(interceptor);
         return buildFrameworkRegistry(module);
     }

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestShutdown.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestShutdown.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestShutdown.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestShutdown.java Wed Feb 21 13:28:12 2007
@@ -23,7 +23,7 @@
 import org.apache.hivemind.definition.ImplementationConstructor;
 import org.apache.hivemind.definition.ImplementationDefinition;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceImplementationDefinitionImpl;
+import org.apache.hivemind.definition.impl.ImplementationDefinitionImpl;
 import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
 import org.apache.hivemind.events.RegistryShutdownListener;
 import org.apache.hivemind.internal.AbstractServiceImplementationConstructor;
@@ -166,7 +166,7 @@
                 return result;
             }};
         
-        ImplementationDefinition impl = new ServiceImplementationDefinitionImpl(module, newLocation(),
+        ImplementationDefinition impl = new ImplementationDefinitionImpl(module, newLocation(),
                 constructor, serviceModel, true);
         sp1.addImplementation(impl);
         module.addServicePoint(sp1);

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestStartup.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestStartup.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestStartup.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestStartup.java Wed Feb 21 13:28:12 2007
@@ -23,8 +23,8 @@
 import org.apache.hivemind.Registry;
 import org.apache.hivemind.definition.Contribution;
 import org.apache.hivemind.definition.ContributionContext;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.impl.StartupImpl;
 import org.apache.hivemind.internal.ServiceModel;

Modified: hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestThreadedModel.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestThreadedModel.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestThreadedModel.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/TestThreadedModel.java Wed Feb 21 13:28:12 2007
@@ -20,8 +20,8 @@
 
 import org.apache.hivemind.HiveMind;
 import org.apache.hivemind.Registry;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.internal.ServiceModel;
 import org.apache.hivemind.service.ThreadEventNotifier;

Modified: hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestBeanService.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestBeanService.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestBeanService.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestBeanService.java Wed Feb 21 13:28:12 2007
@@ -16,8 +16,8 @@
 
 import hivemind.test.FrameworkTestCase;
 
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.internal.ServiceModel;
 

Modified: hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestToString.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestToString.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestToString.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/TestToString.java Wed Feb 21 13:28:12 2007
@@ -22,7 +22,7 @@
 import org.apache.hivemind.definition.ImplementationDefinition;
 import org.apache.hivemind.definition.Visibility;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceImplementationDefinitionImpl;
+import org.apache.hivemind.definition.impl.ImplementationDefinitionImpl;
 import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
 import org.apache.hivemind.impl.InterceptorStackImpl;
 import org.apache.hivemind.impl.ModuleImpl;
@@ -56,7 +56,7 @@
         ModuleDefinition md = new ModuleDefinitionImpl("module", null, null, null);
         ServicePointDefinitionImpl spd = new ServicePointDefinitionImpl(md, "service", null,
                 Visibility.PUBLIC, Runnable.class.getName());
-        ImplementationDefinition sid = new ServiceImplementationDefinitionImpl(md, 
+        ImplementationDefinition sid = new ImplementationDefinitionImpl(md, 
                 null, null, ServiceModel.PRIMITIVE, true);
         spd.addImplementation(sid);
         new ServicePointImpl(module, spd).toString();

Modified: hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestInterceptors.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestInterceptors.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestInterceptors.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestInterceptors.java Wed Feb 21 13:28:12 2007
@@ -23,7 +23,7 @@
 import org.apache.hivemind.definition.ModuleDefinition;
 import org.apache.hivemind.definition.InterceptorDefinition;
 import org.apache.hivemind.definition.Visibility;
-import org.apache.hivemind.definition.impl.OrderedServiceInterceptorDefinitionImpl;
+import org.apache.hivemind.definition.impl.OrderedInterceptorDefinitionImpl;
 import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
 import org.apache.hivemind.internal.Module;
 
@@ -63,10 +63,10 @@
         ModuleDefinition moduleDef = createModuleDefinition("module");
         ServicePointImpl sp = newServicePoint(moduleDef, l, module);
         
-        InterceptorDefinition interceptor1 = new OrderedServiceInterceptorDefinitionImpl(moduleDef, "Interceptor1", null, null,
+        InterceptorDefinition interceptor1 = new OrderedInterceptorDefinitionImpl(moduleDef, "Interceptor1", null, null,
                 null, null);
         sp.getServicePointDefinition().addInterceptor(interceptor1);
-        InterceptorDefinition interceptor2 = new OrderedServiceInterceptorDefinitionImpl(moduleDef, "Interceptor2", null, null,
+        InterceptorDefinition interceptor2 = new OrderedInterceptorDefinitionImpl(moduleDef, "Interceptor2", null, null,
                 null, null);
         sp.getServicePointDefinition().addInterceptor(interceptor2);
 //        sp.getServicePointDefinition()setExtensionPointId("ExtensionPointId");
@@ -88,10 +88,10 @@
         ModuleDefinition moduleDef = createModuleDefinition("module");
         ServicePointImpl sp = newServicePoint(moduleDef, l, module);
         
-        InterceptorDefinition interceptor1 = new OrderedServiceInterceptorDefinitionImpl(moduleDef, "Interceptor1", null, null,
+        InterceptorDefinition interceptor1 = new OrderedInterceptorDefinitionImpl(moduleDef, "Interceptor1", null, null,
                 null, null);
         sp.getServicePointDefinition().addInterceptor(interceptor1);
-        InterceptorDefinition interceptor2 = new OrderedServiceInterceptorDefinitionImpl(moduleDef, "Interceptor2", null, null,
+        InterceptorDefinition interceptor2 = new OrderedInterceptorDefinitionImpl(moduleDef, "Interceptor2", null, null,
                 null, "Interceptor1");
         sp.getServicePointDefinition().addInterceptor(interceptor2);
         final List ordered = sp.getOrderedInterceptorContributions();

Modified: hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestServicePoint.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestServicePoint.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestServicePoint.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/TestServicePoint.java Wed Feb 21 13:28:12 2007
@@ -25,7 +25,7 @@
 import org.apache.hivemind.Location;
 import org.apache.hivemind.definition.ModuleDefinition;
 import org.apache.hivemind.definition.Visibility;
-import org.apache.hivemind.definition.impl.ServiceImplementationDefinitionImpl;
+import org.apache.hivemind.definition.impl.ImplementationDefinitionImpl;
 import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
 import org.apache.hivemind.internal.Module;
 import org.apache.hivemind.internal.ServiceModel;
@@ -87,7 +87,7 @@
 
         ModuleDefinition moduleDef = createModuleDefinition("foo");
         ServicePointDefinitionImpl definition = new ServicePointDefinitionImpl(moduleDef, "bar", l, Visibility.PUBLIC, "java.util.List");
-        definition.addImplementation(new ServiceImplementationDefinitionImpl(moduleDef, l, null, "fred", true));
+        definition.addImplementation(new ImplementationDefinitionImpl(moduleDef, l, null, "fred", true));
         ServicePointImpl sp = new ServicePointImpl(module, definition);
 
         Object service = new ArrayList();

Modified: hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/servicemodel/TestRegistryShutdownListenerServices.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/servicemodel/TestRegistryShutdownListenerServices.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/servicemodel/TestRegistryShutdownListenerServices.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/impl/servicemodel/TestRegistryShutdownListenerServices.java Wed Feb 21 13:28:12 2007
@@ -20,8 +20,8 @@
 import org.apache.hivemind.ShutdownCoordinator;
 import org.apache.hivemind.definition.ImplementationConstructionContext;
 import org.apache.hivemind.definition.ImplementationConstructor;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.internal.AbstractServiceImplementationConstructor;
 import org.apache.hivemind.internal.ServiceModel;

Modified: hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/service/impl/TestLoggingInterceptorFactory.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/service/impl/TestLoggingInterceptorFactory.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/service/impl/TestLoggingInterceptorFactory.java (original)
+++ hivemind/hivemind2/trunk/framework/src/test/org/apache/hivemind/service/impl/TestLoggingInterceptorFactory.java Wed Feb 21 13:28:12 2007
@@ -26,7 +26,7 @@
 import org.apache.hivemind.definition.RegistryDefinition;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.definition.impl.RegistryDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceImplementationDefinitionImpl;
+import org.apache.hivemind.definition.impl.ImplementationDefinitionImpl;
 import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
 import org.apache.hivemind.impl.InterceptorStackImpl;
 import org.apache.hivemind.internal.ServiceModel;
@@ -131,7 +131,7 @@
         definition.addModule(module);
         
         ServicePointDefinitionImpl sp1 = createServicePointDefinition(module, "BeanInterface", BeanInterface.class);
-        ImplementationDefinition impl = new ServiceImplementationDefinitionImpl(module, newLocation(),
+        ImplementationDefinition impl = new ImplementationDefinitionImpl(module, newLocation(),
                 constructor, ServiceModel.SINGLETON, true);
         sp1.addImplementation(impl);
         module.addServicePoint(sp1);

Modified: hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlCoreServicesProvider.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlCoreServicesProvider.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlCoreServicesProvider.java (original)
+++ hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlCoreServicesProvider.java Wed Feb 21 13:28:12 2007
@@ -31,10 +31,10 @@
 import org.apache.hivemind.definition.ImplementationConstructionContext;
 import org.apache.hivemind.definition.ImplementationConstructor;
 import org.apache.hivemind.definition.ModuleDefinition;
-import org.apache.hivemind.definition.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.RegistryDefinition;
 import org.apache.hivemind.definition.RegistryDefinitionPostProcessor;
 import org.apache.hivemind.definition.ServicePointDefinition;
+import org.apache.hivemind.definition.impl.ModuleDefinitionHelper;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
 import org.apache.hivemind.internal.AbstractServiceImplementationConstructor;
 import org.apache.hivemind.internal.ServiceModel;

Modified: hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlModuleDescriptorProcessor.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlModuleDescriptorProcessor.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlModuleDescriptorProcessor.java (original)
+++ hivemind/hivemind2/trunk/xml/src/java/org/apache/hivemind/impl/XmlModuleDescriptorProcessor.java Wed Feb 21 13:28:12 2007
@@ -34,8 +34,8 @@
 import org.apache.hivemind.definition.impl.ConfigurationPointDefinitionImpl;
 import org.apache.hivemind.definition.impl.ContributionDefinitionImpl;
 import org.apache.hivemind.definition.impl.ModuleDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceImplementationDefinitionImpl;
-import org.apache.hivemind.definition.impl.ServiceInterceptorDefinitionImpl;
+import org.apache.hivemind.definition.impl.ImplementationDefinitionImpl;
+import org.apache.hivemind.definition.impl.InterceptorDefinitionImpl;
 import org.apache.hivemind.definition.impl.ServicePointDefinitionImpl;
 import org.apache.hivemind.parse.ConfigurationPointDescriptor;
 import org.apache.hivemind.parse.ContributionDescriptor;
@@ -226,7 +226,7 @@
         List interceptors = id.getInterceptors();
 
         if (builder != null) {
-            ServiceImplementationDefinitionImpl implementation = new ServiceImplementationDefinitionImpl(
+            ImplementationDefinitionImpl implementation = new ImplementationDefinitionImpl(
                     sourceModule, builder.getLocation(), builder.createConstructor(sourceModule.getId()),
                     builder.getServiceModel(), false);
             sourceModule.addImplementation(qualifiedPointId, implementation); 
@@ -256,7 +256,7 @@
             return;
 
         if (builder != null) {
-            ImplementationDefinition implementation = new ServiceImplementationDefinitionImpl(
+            ImplementationDefinition implementation = new ImplementationDefinitionImpl(
                     module, builder.getLocation(), builder.createConstructor(module.getId()),
                     builder.getServiceModel(), false);
             point.addImplementation(implementation);
@@ -357,7 +357,7 @@
         constructor.setParameters(id.getParameters());
         constructor.setPrecedingInterceptorIds(id.getAfter());
         constructor.setFollowingInterceptorIds(id.getBefore());
-        ServiceInterceptorDefinitionImpl interceptor = new ServiceInterceptorDefinitionImpl(
+        InterceptorDefinitionImpl interceptor = new InterceptorDefinitionImpl(
                 module, id.getName(), id.getLocation(), constructor);
         module.addInterceptor(qualifiedPointId, interceptor);
     }

Copied: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ClassResolverHolder.java (from r505487, hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/ClassResolverHolder.java)
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ClassResolverHolder.java?view=diff&rev=510236&p1=hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/ClassResolverHolder.java&r1=505487&p2=hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ClassResolverHolder.java&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ConstructClassResolver.xml (original)
+++ hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ConstructClassResolver.xml Wed Feb 21 13:28:12 2007
@@ -16,9 +16,9 @@
 -->
 
 <module id="hivemind.test.services" version="1.0.0">
-    <service-point id="ConstructClassResolver" interface="hivemind.test.services.ClassResolverHolder">
+    <service-point id="ConstructClassResolver" interface="org.apache.hivemind.service.ClassResolverHolder">
         <invoke-factory>
-            <construct class="hivemind.test.services.impl.ClassResolverHolderImpl">
+            <construct class="org.apache.hivemind.service.impl.ClassResolverHolderImpl">
                 <class-resolver/>
             </construct>
         </invoke-factory>

Modified: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/InitializeMethodFailure.xml
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/InitializeMethodFailure.xml?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/InitializeMethodFailure.xml (original)
+++ hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/InitializeMethodFailure.xml Wed Feb 21 13:28:12 2007
@@ -18,7 +18,7 @@
 <module id="hivemind.test.services" version="1.0.0">
     <service-point id="Runnable" interface="java.lang.Runnable">
         <invoke-factory>
-            <construct class="hivemind.test.services.impl.MockRunnable" initialize-method="doesNotExist"/>
+            <construct class="org.apache.hivemind.service.impl.MockRunnable" initialize-method="doesNotExist"/>
         </invoke-factory>
     </service-point>
 </module>

Modified: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/SetClassResolver.xml
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/SetClassResolver.xml?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/SetClassResolver.xml (original)
+++ hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/SetClassResolver.xml Wed Feb 21 13:28:12 2007
@@ -16,10 +16,10 @@
 -->
 
 <module id="hivemind.test.services" version="1.0.0">
-    <service-point id="SetClassResolver" interface="hivemind.test.services.ClassResolverHolder">
+    <service-point id="SetClassResolver" interface="org.apache.hivemind.service.ClassResolverHolder">
         <invoke-factory>
             <construct
-                class="hivemind.test.services.impl.ClassResolverHolderImpl" class-resolver-property="classResolver"/>
+                class="org.apache.hivemind.service.impl.ClassResolverHolderImpl" class-resolver-property="classResolver"/>
         </invoke-factory>
     </service-point>
 </module>

Modified: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/TestBuilderFactory.java
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/TestBuilderFactory.java?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/TestBuilderFactory.java (original)
+++ hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/TestBuilderFactory.java Wed Feb 21 13:28:12 2007
@@ -15,7 +15,6 @@
 package org.apache.hivemind.service;
 
 import hivemind.test.services.AutowireTarget;
-import hivemind.test.services.ClassResolverHolder;
 import hivemind.test.services.ConstructorAutowireTarget;
 import hivemind.test.services.ErrorHandlerHolder;
 import hivemind.test.services.InitializeFixture;
@@ -82,7 +81,7 @@
 
         assertLoggedMessagePattern("Error at .*?: Unable to initialize service hivemind\\.test\\.services\\.Runnable "
                 + "\\(by invoking method doesNotExist on "
-                + "hivemind\\.test\\.services\\.impl\\.MockRunnable\\):");
+                + "org\\.apache\\.hivemind\\.service\\.impl\\.MockRunnable\\):");
     }
 
     public void testBuilderErrorHandlerFacet()

Copied: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/ClassResolverHolderImpl.java (from r505487, hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/impl/ClassResolverHolderImpl.java)
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/ClassResolverHolderImpl.java?view=diff&rev=510236&p1=hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/impl/ClassResolverHolderImpl.java&r1=505487&p2=hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/ClassResolverHolderImpl.java&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/ClassResolverHolder.java (original)
+++ hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ClassResolverHolder.java Wed Feb 21 13:28:12 2007
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package hivemind.test.services;
+package org.apache.hivemind.service;
 
 import org.apache.hivemind.ClassResolver;
 
 /**
  * Used with the {@link hivemind.test.services.TestBuilderFactory} tests.
  *
  * @author Howard Lewis Ship
  */

Propchange: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ClassResolverHolder.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.3

Propchange: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ClassResolverHolder.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ClassResolverHolder.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision
@@ -12,12 +12,12 @@
 
 /**
- * Used with the {@link hivemind.test.services.TestBuilderFactory} tests.
+ * Used with the {@link org.apache.hivemind.service.TestBuilderFactory} tests.
  *
  * @author Howard Lewis Ship

Modified: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ConstructClassResolver.xml
URL: http://svn.apache.org/viewvc/hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/ConstructClassResolver.xml?view=diff&rev=510236&r1=510235&r2=510236
==============================================================================
--- hivemind/hivemind2/trunk/framework/src/test/hivemind/test/services/impl/ClassResolverHolderImpl.java (original)
+++ hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/ClassResolverHolderImpl.java Wed Feb 21 13:28:12 2007
@@ -12,14 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package hivemind.test.services.impl;
+package org.apache.hivemind.service.impl;
 
-import hivemind.test.services.ClassResolverHolder;
 
 import org.apache.hivemind.ClassResolver;
+import org.apache.hivemind.service.ClassResolverHolder;
+import org.apache.hivemind.service.TestBuilderFactory;
 
 /**
  * Used with {@link hivemind.test.services.TestBuilderFactory}.
  *
  * @author Howard Lewis Ship
  */

Propchange: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/ClassResolverHolderImpl.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.3

Propchange: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/ClassResolverHolderImpl.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: hivemind/hivemind2/trunk/xml/src/test/org/apache/hivemind/service/impl/ClassResolverHolderImpl.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision
@@ -12,14 +12,15 @@
 
 /**
- * Used with {@link hivemind.test.services.TestBuilderFactory}.
+ * Used with {@link org.apache.hivemind.service.TestBuilderFactory}.
  *
  * @author Howard Lewis Ship